# PDFSNIPPER
A package to help manage pdf pages, images and their conversions during different NLP, CV or other tasks to avoid repetitive code blocks and give a simple function call to make it happen

### If you face the error involving `poppler-utlils`
        1.For Google Colab -> !apt-get install -y poppler-utils
        2. Ubuntu/Debian -> sudo apt install poppler-utils




